Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(202)

Unified Diff: components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h

Issue 962903003: Rename WebDataServiceBackend to WebDatabaseBackend (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase and fix nits Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/autofill/core/browser/webdata/autofill_webdata_backend_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h
diff --git a/components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h b/components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h
index 027abbf8be8bb83a094fa0c334543db866db0587..f7572b7921dba5e03756bc16b4d74deba076dbc7 100644
--- a/components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h
+++ b/components/autofill/core/browser/webdata/autofill_webdata_backend_impl.h
@@ -22,7 +22,7 @@ namespace base {
class MessageLoopProxy;
}
-class WebDataServiceBackend;
+class WebDatabaseBackend;
namespace autofill {
@@ -47,7 +47,7 @@ class AutofillWebDataBackendImpl
// thread of changes initiated by Sync (this callback may be called multiple
// times).
AutofillWebDataBackendImpl(
- scoped_refptr<WebDataServiceBackend> web_database_backend,
+ scoped_refptr<WebDatabaseBackend> web_database_backend,
scoped_refptr<base::MessageLoopProxy> ui_thread,
scoped_refptr<base::MessageLoopProxy> db_thread,
const base::Closure& on_changed_callback);
@@ -201,9 +201,9 @@ class AutofillWebDataBackendImpl
ObserverList<AutofillWebDataServiceObserverOnDBThread> db_observer_list_;
// WebDataServiceBackend allows direct access to DB.
// TODO(caitkp): Make it so nobody but us needs direct DB access anymore.
- scoped_refptr<WebDataServiceBackend> web_database_backend_;
+ scoped_refptr<WebDatabaseBackend> web_database_backend_;
base::Closure on_changed_callback_;
« no previous file with comments | « no previous file | components/autofill/core/browser/webdata/autofill_webdata_backend_impl.cc » ('j') | no next file with comments »
@@ -201,9 +201,9 @@ class AutofillWebDataBackendImpl
ObserverList<AutofillWebDataServiceObserverOnDBThread> db_observer_list_;
- // WebDataServiceBackend allows direct access to DB.
+ // WebDatabaseBackend allows direct access to DB.
// TODO(caitkp): Make it so nobody but us needs direct DB access anymore.

Powered by Google App Engine
This is Rietveld 408576698